@@ -76,8 +76,10 @@ static action_type check_action_type(xmlChar* type);
 static signal_data* convert_to_handler_format(xmlDocPtr doc, 
                                               action_type* action);
 
-
+#ifdef TEST
 #define INCLUDE_HANDLER_TEST_FUNC 1
+#endif
+
 #ifdef INCLUDE_HANDLER_TEST_FUNC
 #include "../../test/kernel_test/handler_test_func.c"
 #endif
@@ -550,7 +552,9 @@ static signal_data* convert_to_handler_format(xmlDocPtr doc,
 
     tmp_node = find_sibling_node_by_name(inner_root_node->children, 
                                          BAD_CAST ACTION_TAG_NAME);
-    (*action) = check_action_type(xmlNodeGetContent(tmp_node));	
+    xmlChar* action_type = xmlNodeGetContent(tmp_node);                                         
+    (*action) = check_action_type(action_type);	
+    xmlFree(action_type);
     
     signal->id = xmlGetProp(inner_root_node, BAD_CAST SIGNAL_ATTR_ID);
     
