@@ -271,6 +271,15 @@ gboolean ui_driver_get_profile(gpointer request)
         }
         node = node->next;
     }    
+    
+    gchar* file_path = (gchar*)xmlNodeGetContent(cont);
+    GtkWidget* image = NULL;
+    if(g_file_test(file_path, G_FILE_TEST_EXISTS) == TRUE){
+        
+        image = gtk_image_new_from_file(file_path);
+        gtk_misc_set_alignment(GTK_MISC(image), 0.5, 0.5);
+
+/*
     guchar* buff; 
     guchar* undecoded;
     GdkPixbuf* pixbuff;  
@@ -291,6 +300,7 @@ gboolean ui_driver_get_profile(gpointer request)
         g_object_unref(pixbuff);
         pixbuff = npixbuff;
     }
+
     GtkWidget* image = gtk_image_new_from_pixbuf(pixbuff);
     gtk_misc_set_alignment(GTK_MISC(image), 0.5, 0.5);
     gdk_pixbuf_loader_close(pbloader, NULL);
@@ -300,6 +310,9 @@ gboolean ui_driver_get_profile(gpointer request)
     g_free(buff);
     g_object_unref(pixbuff);
     g_free(undecoded);
+*/
+    }
+    g_free(file_path);
     gtk_box_pack_start(GTK_BOX(hbox_edit), image, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(hbox_edit), vbox_left, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(hbox_edit), vbox_edit, TRUE, TRUE, 0);
@@ -362,7 +375,12 @@ static gpointer ui_init_date_chooser(gchar* str_label, gchar* str_value)
         d = atoi(numbers[0]);
     }
     g_strfreev(numbers);
-    GtkWidget* button = hildon_date_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
+    GDate* date = g_date_new();
+    GTimeVal* ctime;
+    g_get_current_time(ctime);
+    g_date_set_time_val(date, ctime);
+    GtkWidget* button = hildon_date_button_new_with_year_range(HILDON_SIZE_FINGER_HEIGHT, NULL, MIN_YEAR,  (int)g_date_get_year(date) - 12);
+    g_date_free(date);
     hildon_date_button_set_date (button, y, m, d);
     
     hildon_button_set_title(button, NULL);
@@ -379,6 +397,7 @@ static gpointer ui_init_date_chooser(gchar* str_label, gchar* str_value)
  */
 gboolean ui_driver_get_friends(gpointer request)
 {
+
     xmlXPathObject *Obj;
     xmlNodePtr node_root;
     xmlNodePtr node;
@@ -446,9 +465,6 @@ gboolean ui_driver_get_friends(gpointer request)
     gtk_widget_show_all(ui_data->box_friends_list);
 
 
-
-
-    
     if (ui_data->friends_offline && str_filter == NULL) gtk_widget_show(ui_data->box_friends_navi);
     else gtk_widget_hide(ui_data->box_friends_navi);
     
@@ -495,9 +511,11 @@ gpointer ui_friend(gpointer ptr_friend)
 
     gtk_misc_set_alignment(GTK_MISC(label_name), 0, 0.5);
     gtk_label_set_ellipsize(GTK_LABEL(label_name), PANGO_ELLIPSIZE_END);
-    gtk_widget_set_name (GTK_WIDGET(label_name), friend->str_name);
-    if (strlen(friend->str_img) > 0) { 
-        int size;    
+    gtk_widget_set_name (GTK_WIDGET(label_name), friend->str_name); 
+    //if (strlen(friend->str_img) > 0) { 
+    if(g_file_test(friend->str_img, G_FILE_TEST_EXISTS) == TRUE){
+        /*int size;
+
         guchar* buff = g_base64_decode(friend->str_img, &size);    
 
         GdkPixbufLoader* pbloader = gdk_pixbuf_loader_new_with_type ("jpeg", NULL);
@@ -513,10 +531,12 @@ gpointer ui_friend(gpointer ptr_friend)
         g_object_unref(pixbuff_prev);
 
         GdkPixbuf* pixbuffsquare = gdk_pixbuf_new(gdk_pixbuf_get_colorspace(pixbuff), FALSE, gdk_pixbuf_get_bits_per_sample(pixbuff), width, height);
-        gdk_pixbuf_copy_area(pixbuff, 0, 0, gdk_pixbuf_get_width(pixbuff), height, pixbuffsquare, 0, 0);
+        gdk_pixbuf_copy_area(pixbuff, 0, 0, gdk_pixbuf_get_width(pixbuff), height, pixbuffsquare, 0, 0);   
         image = gtk_image_new_from_pixbuf(pixbuffsquare);    
         g_object_unref(pixbuff);
         g_object_unref(pixbuffsquare);
+*/
+        image = gtk_image_new_from_file(friend->str_img);
     } else {
         image = gtk_image_new_from_file(IMG_CONT);
         gpointer obj = (gpointer)image;
@@ -539,10 +559,11 @@ gpointer ui_friend(gpointer ptr_friend)
     gtk_widget_show_all(GTK_CONTAINER(ui_data->box_profile));
     gtk_button_set_relief(GTK_BUTTON(button_msg), GTK_RELIEF_NONE);
     gtk_container_add(GTK_CONTAINER(button_prf), box_button_prf);
-    gtk_container_add(GTK_CONTAINER(button_msg), box_button_msg);
+    hildon_button_set_image(button_msg, gtk_image_new_from_icon_name("general_sms_button", GTK_ICON_SIZE_BUTTON));
+    //gtk_container_add(GTK_CONTAINER(button_msg), box_button_msg);
     gtk_box_pack_start(GTK_BOX (box_button_prf), image, FALSE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX (box_button_prf), label_name, TRUE, TRUE, PADDING);
-    gtk_box_pack_start(GTK_BOX (box_button_msg), gtk_image_new_from_file(IMG_COMP), TRUE, TRUE, 0);
+    //gtk_box_pack_start(GTK_BOX (box_button_msg), gtk_image_new_from_file(IMG_COMP), TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(hbox), button_prf, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(box_button_prf), button_msg, FALSE, TRUE, 0);    
     ptr_str_id = g_strdup(friend->str_id);
@@ -645,33 +666,12 @@ gboolean ui_driver_get_friends_profile(gpointer request)
         node = node->next;
     }
     
-    guchar* buff; 
-    GdkPixbuf* pixbuff;  
-    int size;    
     gchar* node_content;
     node_content = (gchar*)xmlNodeGetContent(cont);
-    buff = g_base64_decode(node_content, &size);
-    g_free(node_content);
-    GdkPixbufLoader* pbloader;
-    pbloader = gdk_pixbuf_loader_new_with_type ("jpeg", NULL);
-    gdk_pixbuf_loader_write(pbloader, buff, size, NULL);
-    GdkPixbuf *pix_orig = gdk_pixbuf_loader_get_pixbuf(pbloader);
-    gdk_pixbuf_loader_close (pbloader, NULL);
-    
-    int height = gdk_pixbuf_get_height(pix_orig);
-    if (height > MAX_HEIGHT_PHOTO) {
-        int width = gdk_pixbuf_get_width(pix_orig) * MAX_HEIGHT_PHOTO / height;
-        height = MAX_HEIGHT_PHOTO;
-        pixbuff = gdk_pixbuf_scale_simple (pix_orig, width, height, GDK_INTERP_BILINEAR);
-        g_object_unref(pix_orig);
-    } else {
-        pixbuff = pix_orig;
-    }        
-    GtkWidget* image = gtk_image_new_from_pixbuf (pixbuff);
-    g_object_unref(pixbuff);
-    //g_object_unref(pbloader);
-    g_free(buff);
-
+    GtkWidget* image;
+    if(g_file_test(node_content, G_FILE_TEST_EXISTS) == TRUE){
+        image = gtk_image_new_from_file(node_content);
+    }
     
     gtk_box_pack_start(GTK_BOX(hbox_details), vbox_left, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(hbox_details), vbox_right, TRUE, TRUE, PADDING);
@@ -1167,6 +1167,7 @@ gboolean ui_show_error(gpointer request)
      
     if (obj != NULL && obj->nodesetval->nodeNr != 0) {
         text = xmlNodeGetContent(obj->nodesetval->nodeTab[0]);
+        g_debug("%s",text);
         xmlXPathFreeObject(obj);
     }
     else {
@@ -1189,7 +1190,10 @@ gboolean ui_show_error(gpointer request)
             gtk_widget_destroy(children->data); 
         }
         gtk_widget_hide(ui_data->box_friends_navi);
-        callback_button_friends_update(NULL, NULL);
+        if (ui_data->empty_friends){
+            callback_button_friends_update(NULL, NULL);
+            ui_data->empty_friends = FALSE;
+        }
     }
     if(strcmp(code, DB_ERROR_SEARCH_FRIENDS_CODE) == 0) {
         show = FALSE;
