@@ -236,7 +236,7 @@ void callback_button_profile_get(GtkWidget* button, gpointer data)
 **/
 void callback_button_friends_get(GtkWidget* button, gpointer data)
 {
-    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
+   //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     int from = FRIENDS_PER_PAGE*ui_data->page_frds;
     int to = FRIENDS_PER_PAGE*(ui_data->page_frds + 1);
     int online = ui_data->friends_offline ? 0 : 1;
@@ -327,7 +327,7 @@ void callback_button_friends_result(GtkWidget* button_cb, gpointer data)
 void callback_button_friends_update(GtkWidget* button, gpointer data)
 {
     xmlDocPtr resp = NULL;
-    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
+   //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc("<?xml version=\"1.0\"?><TransitData id=\"1\" \
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
@@ -429,7 +429,7 @@ void callback_button_messages_get(GtkWidget* button, gpointer data)
     <TargetID>db</TargetID>\
     <Content><Request class=\"messages\" function = \"get",str_msgs_box,"Messages\"><Params From=\"",sfrom,
     "\" To=\"",sto,"\"></Params></Request></Content></TransitData>",NULL);
-    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
+   //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc(request), NULL, NULL);
 
     g_free(request);
@@ -450,6 +450,9 @@ void callback_message_reply(GtkWidget* container, gpointer data)
     gtk_window_set_title(GTK_WINDOW(window_msg), STR_PROG);
     gtk_container_add(GTK_CONTAINER((GtkWidget*)window_msg), ui_init_message_reply(data));
     gtk_widget_show(GTK_WIDGET(window_msg));
+    
+    //FIXME send request to mark message as read
+    
     return;
 }
 
@@ -613,7 +616,7 @@ void callback_button_messages_update(GtkWidget* button, gpointer data)
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
     <Content><Request class=\"messages\" function = \"update", str_msgs_box, "Messages\"><Params></Params></Request></Content></TransitData>", NULL);
-    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
+   //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc(request), NULL, NULL);
     g_free(request);
     g_free(str_msgs_box);
@@ -721,7 +724,7 @@ void callback_button_friends_profile_update(GtkWidget* button, gpointer data)
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
     <Content><Request class=\"profile\" function = \"updateProfile\"><Params id=\"",(gchar*)data,"\"></Params></Request></Content></TransitData>",NULL);
-    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
+   //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc(request), NULL, NULL);
     g_free(request);
 }
@@ -857,8 +860,9 @@ void callback_friends_join(GtkWidget* button_cb, gpointer data)
 **/
 void callback_button_friends_show_offline(GtkWidget* button, gpointer data)
 {
-    if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)) != ui_data->friends_offline) {
+    if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)) == ui_data->friends_offline) {
         ui_data->friends_offline = !ui_data->friends_offline;
+        gtk_button_set_label(GTK_BUTTON(button), ui_data->friends_offline ? STR_HIDE : STR_SHOW);
         ui_data->page_frds = 0;
         callback_button_friends_get(NULL, NULL);
     }
@@ -1002,7 +1006,7 @@ void callback_button_friend_get(GtkWidget* button, gpointer data)
         type=\"data\"><SourceID>ui</SourceID>\
         <TargetID>db</TargetID>\
         <Content><Request class=\"profile\" function = \"getProfile\"><Params id=\"", (gchar*)data, "\"></Params></Request></Content></TransitData>", NULL);
-    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
+   //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc(request), NULL, NULL);
     g_free(request);
 }
@@ -1015,7 +1019,7 @@ void callback_button_friend_get(GtkWidget* button, gpointer data)
 **/
 void callback_button_profile_update(GtkWidget* button, gpointer data)
 {
-    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
+   //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc("<?xml version=\"1.0\"?><TransitData id=\"1\" \
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
@@ -1293,7 +1297,7 @@ void callback_task_switch(GtkWidget* notebook, GtkNotebookPage* page, guint page
         break;
     case 2:
         if (ui_data->empty_messages) {
-            callback_button_messages_update(NULL, NULL);
+            callback_button_messages_get(NULL, NULL);
             ui_data->empty_messages = FALSE;
         } else {
             callback_button_messages_get(NULL, NULL);
