@@ -76,6 +76,8 @@ static void ui_init_tasks()
     GtkWidget* button_prfl_1 = GTK_WIDGET(ui_init_button_service());
     GtkWidget* button_prfl_2 = GTK_WIDGET(hildon_button_new_with_text(HILDON_SIZE_FINGER_HEIGHT, NULL, STR_UPDT, NULL));
     GtkWidget* button_prfl_3 = GTK_WIDGET(hildon_button_new_with_text(HILDON_SIZE_FINGER_HEIGHT, NULL, STR_SAVE, NULL));
+    hildon_button_set_image(button_prfl_2, gtk_image_new_from_icon_name("general_refresh", GTK_ICON_SIZE_BUTTON));
+    hildon_button_set_image(button_prfl_3, gtk_image_new_from_icon_name("widgets_tickmark_list", GTK_ICON_SIZE_BUTTON));
     gtk_box_pack_start(GTK_BOX(ui_data->taskboxes[0]), ui_data->box_profile, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(ui_data->taskboxes[0]), box_prfl, FALSE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(box_prfl), button_prfl_1, TRUE, TRUE, 0);
@@ -102,7 +104,7 @@ static void ui_init_tasks()
     GtkWidget* box_friends_show_offl = gtk_vbox_new(FALSE, 0);
     ui_data->label_friends_page = gtk_label_new(STR_EMPT);
     ui_data->button_friends_show_offl = GTK_WIDGET(hildon_gtk_toggle_button_new(HILDON_SIZE_FINGER_HEIGHT)); 
-    gtk_toggle_button_set_active(GTK_BUTTON(ui_data->button_friends_show_offl), ui_data->friends_offline);
+    gtk_toggle_button_set_active(GTK_BUTTON(ui_data->button_friends_show_offl), !ui_data->friends_offline);
     ui_data->button_friends_page_prev = GTK_WIDGET(hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL));
     ui_data->button_friends_page_next = GTK_WIDGET(hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL));
     ui_data->button_friends_page_frst = GTK_WIDGET(hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL));
@@ -112,10 +114,15 @@ static void ui_init_tasks()
     gtk_button_set_relief(GTK_BUTTON(ui_data->button_friends_page_frst), GTK_RELIEF_NONE);
     gtk_button_set_relief(GTK_BUTTON(ui_data->button_friends_page_last), GTK_RELIEF_NONE);
     gtk_button_set_label (GTK_BUTTON(ui_data->button_friends_show_offl), STR_SHOW);
+    //hildon_button_set_image(ui_data->button_friends_page_prev, gtk_image_new_from_stock(GTK_STOCK_GO_BACK, GTK_ICON_SIZE_SMALL_TOOLBAR));
     hildon_button_set_image(ui_data->button_friends_page_prev, gtk_image_new_from_file(IMG_PREV));
     hildon_button_set_image(ui_data->button_friends_page_next, gtk_image_new_from_file(IMG_NEXT));
     hildon_button_set_image(ui_data->button_friends_page_frst, gtk_image_new_from_file(IMG_FRST));
     hildon_button_set_image(ui_data->button_friends_page_last, gtk_image_new_from_file(IMG_LAST));
+    //hildon_button_set_image(ui_data->button_friends_page_prev, gtk_image_new_from_icon_name("general_back", GTK_ICON_SIZE_SMALL_TOOLBAR));
+    //hildon_button_set_image(ui_data->button_friends_page_next, gtk_image_new_from_icon_name("general_forward", GTK_ICON_SIZE_SMALL_TOOLBAR));
+    //hildon_button_set_image(ui_data->button_friends_page_frst, gtk_image_new_from_icon_name("gtk_stock_goto_first", GTK_ICON_SIZE_SMALL_TOOLBAR));
+    //hildon_button_set_image(ui_data->button_friends_page_last, gtk_image_new_from_icon_name("pdf_viewer_last_page", GTK_ICON_SIZE_SMALL_TOOLBAR));
     gtk_box_pack_start(GTK_BOX(box_friends_show_offl), ui_data->button_friends_show_offl, TRUE, TRUE, 0); 
     gtk_box_pack_start(GTK_BOX(box_friends_tool), box_friends_show_offl, TRUE, TRUE, 0); 
     gtk_box_pack_start(GTK_BOX(box_friends_tool), ui_data->box_friends_navi, FALSE, TRUE, 0);
@@ -135,7 +142,8 @@ static void ui_init_tasks()
     GtkWidget* button_friends_result = GTK_WIDGET(hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL));
     gtk_button_set_relief(GTK_BUTTON(button_friends_result), GTK_RELIEF_NONE);
     g_signal_connect(G_OBJECT(button_friends_result), "clicked", G_CALLBACK(callback_button_friends_result), NULL);
-    gtk_container_add(GTK_CONTAINER(button_friends_result), gtk_image_new_from_file(IMG_CLER));
+    gtk_button_set_image(button_friends_result, gtk_image_new_from_icon_name("general_close", GTK_ICON_SIZE_BUTTON));
+    //gtk_container_add(GTK_CONTAINER(button_friends_result), gtk_image_new_from_file(IMG_CLER));
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_result), ui_data->label_friends_filter, TRUE, TRUE, 0); 
     gtk_box_pack_start(GTK_BOX(ui_data->box_friends_result), button_friends_result, FALSE, FALSE, 0); 
     gtk_box_pack_start(GTK_BOX(box_friends_tool), ui_data->box_friends_result, FALSE, TRUE, 0);
@@ -201,8 +209,10 @@ static void ui_init_tasks()
     GtkWidget* box_msgs_page = gtk_hbox_new(FALSE, 0);
     GtkWidget* rb1 = GTK_WIDGET(hildon_gtk_radio_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL));
     GtkWidget* rb2 = GTK_WIDGET(hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_FINGER_HEIGHT, GTK_RADIO_BUTTON(rb1)));
-    gtk_button_set_label(GTK_BUTTON(rb1), _(STR_INCM));
-    gtk_button_set_label(GTK_BUTTON(rb2), _(STR_SENT));
+    //gtk_button_set_label(GTK_BUTTON(rb1), _(STR_INCM));
+    gtk_button_set_image(rb1, gtk_image_new_from_icon_name("email_inbox", GTK_ICON_SIZE_BUTTON));
+    gtk_button_set_image(rb2, gtk_image_new_from_icon_name("general_outbox", GTK_ICON_SIZE_BUTTON));
+    //gtk_button_set_label(GTK_BUTTON(rb2), _(STR_SENT));
     gtk_box_pack_start(GTK_BOX(box_msgs_type), GTK_WIDGET(rb1), TRUE, TRUE, 0);
     gtk_box_pack_end(GTK_BOX(box_msgs_type), GTK_WIDGET(rb2), TRUE, TRUE, 0);
     gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(rb1), FALSE);
@@ -212,6 +222,8 @@ static void ui_init_tasks()
     gtk_button_set_relief(GTK_WIDGET(ui_data->button_messages_page_prev), GTK_RELIEF_NONE);
     gtk_button_set_relief(GTK_WIDGET(ui_data->button_messages_page_next), GTK_RELIEF_NONE);
     ui_data->label_messages_page = gtk_label_new(STR_EMPT);
+    //hildon_button_set_image(ui_data->button_messages_page_prev, gtk_image_new_from_icon_name("general_back", GTK_ICON_SIZE_SMALL_TOOLBAR));
+    //hildon_button_set_image(ui_data->button_messages_page_next, gtk_image_new_from_icon_name("general_forward", GTK_ICON_SIZE_SMALL_TOOLBAR));
     gtk_container_add(GTK_CONTAINER(ui_data->button_messages_page_prev), gtk_image_new_from_file(IMG_PREV));
     gtk_container_add(GTK_CONTAINER(ui_data->button_messages_page_next), gtk_image_new_from_file(IMG_NEXT));
     g_signal_connect(G_OBJECT(rb1), "released", G_CALLBACK(callback_button_msgs), (gpointer)0);
@@ -476,9 +488,15 @@ gpointer ui_init_friend_tools(gpointer ptr_str_id)
     GtkWidget* button_nmsg = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
     GtkWidget* button_join = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
     ui_data->button_friend_profile_refresh = button_updt;
-    hildon_button_set_title(button_updt, STR_UPDT);
+    //hildon_button_set_title(button_updt, STR_UPDT);
     hildon_button_set_title(button_join, STR_JOIN);
-    hildon_button_set_title(button_nmsg, STR_NMSG);
+    //hildon_button_set_title(button_nmsg, STR_NMSG);
+    hildon_button_set_image(button_updt, gtk_image_new_from_icon_name("general_refresh", GTK_ICON_SIZE_BUTTON));
+    hildon_button_set_image(button_nmsg, gtk_image_new_from_icon_name("general_sms_button", GTK_ICON_SIZE_BUTTON));
+    gtk_button_set_relief(GTK_BUTTON(button_updt), GTK_RELIEF_NONE);
+    gtk_button_set_relief(GTK_BUTTON(button_nmsg), GTK_RELIEF_NONE);
+    gtk_button_set_relief(GTK_BUTTON(button_srvc), GTK_RELIEF_NONE);
+    gtk_button_set_relief(GTK_BUTTON(button_join), GTK_RELIEF_NONE);
     gtk_widget_set_sensitive(GTK_WIDGET(button_join), FALSE);
     gtk_box_pack_start(GTK_BOX(box), button_srvc, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(box), button_updt, TRUE, TRUE, 0);
